==> haskell-hls-rename-plugin-2.0.0.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-rename-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-rename-plugin-2.0.0.0-EysbI5cwf095nJpRYRk5JS
key:                  hls-rename-plugin-2.0.0.0-EysbI5cwf095nJpRYRk5JS
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  975fe5ad19724ab0393950a182eb884f
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.0.0.0-EysbI5cwf095nJpRYRk5JS
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-EuapY98rdrN25pzQYLq3T2
    ghc-9.4.8 ghc-exactprint-1.6.1-Hhg3PMpjpEKL9mhLS9uk3b
    ghcide-2.0.0.0-239vuqwqb9AHEMUTpbpyg
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hie-compat-0.3.0.0-CbBComUrkWGfIGRN5OUf4
    hiedb-0.4.3.0-BdBRrif8sJk5KhdAwooFOd
    hls-plugin-api-2.0.0.0-C4KP5NWWuu59l1jOYt9ljX
    hls-refactor-plugin-2.0.0.0-GtGGIfl8ggWEpWr0RhAMrT
    lsp-1.6.0.0-2KeiYBxXLvVGpdNjURDfN5
    lsp-types-1.6.0.1-9PlWJ5C3jGZ30kxer1exM3
    mod-0.2.0.1-82dprnJNJy62fnc6HXRgh3
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-FzN23deFW3GkzXU7VwkDd

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-rename-plugin-2.0.0.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-rename-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-rename-plugin-2.0.0.0-42NInUa5R877P17dST1tnL
key:                  hls-rename-plugin-2.0.0.0-42NInUa5R877P17dST1tnL
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  317ceb93c8c07c141d35b5dde0033ad2
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-rename-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.0.0.0-42NInUa5R877P17dST1tnL
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-3SBUeFH5sHLJDtonZSgAoM
    ghc-9.4.8 ghc-exactprint-1.6.1-JsvwkDVofg3BxdLE532wCX
    ghcide-2.0.0.0-3b9jhFA8f52IfzEBIRB0hj
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hie-compat-0.3.0.0-CbBComUrkWGfIGRN5OUf4
    hiedb-0.4.3.0-GJ5ab5bSJo2HJCWa4cU73t
    hls-plugin-api-2.0.0.0-C6wcsLywVi7Dk1nbG5XhP7
    hls-refactor-plugin-2.0.0.0-2MZFAAQYAfR8r0Khl4ZFYq
    lsp-1.6.0.0-FwDzb2GQtLRAHogbqVnKTH
    lsp-types-1.6.0.1-7oBLZTMI1ltETQ1utonnH3
    mod-0.2.0.1-ArIQ1OPgjFiDJkbXD8170X
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
